ItemResolver

Type Alias ItemResolver 

pub type ItemResolver<T> = Callback<String, ItemResolverResult<T>>;
An async function that can be passed as a Prop, that takes the current value of the Autocomplete input and returns a Vec of Ts

Aliased Type

pub struct ItemResolver<T> { /* private fields */ }