Type Definition yew_autocomplete::ItemResolver
source · pub type ItemResolver<T> = FnProp<String, ItemResolverResult<T>>;Expand description
An async function that can be passed as a Prop, that takes the current value of the
Autocomplete input and returns a Vec of Ts